==> nextcloud-23.0.9.tgz: nextcloud/apps/viewer/l10n/da.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Fremviser",
    "Simple file viewer with slideshow for media" : "Simpel filfremviser med slideshow til medie-filer",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Vis dine seneste feriebilledes og videoer som i biografen, vis et glimt af din seneste roman direkte fra din Nextcloud, vis din bedste GIF i din samling gennem forhåndsvisning af dine favoritfiler og meget mere!",
    "Your browser does not support audio." : "Din browser understøtter ikke lyd.",
    "Error loading {name}" : "Fejl ved indlæsning af {name}",
    "Unsaved changes" : "Ikke gemte ændringer",
    "Your browser does not support videos." : "Din browser understøtter ikke videoer.",
    "Edit" : "Rediger",
    "Open sidebar" : "Åbn sidebar",
    "Download" : "Download",
    "Delete" : "Slet",
    "There is no plugin available to display this file type" : "Der er intet plugin tilgængeligt til at vise denne filtype",
    "View" : "Vis",
    "Name" : "Navn",
    "Save" : "Gem",
    "Back" : "Tilbage",
    "Loading …" : "Loading …",
    "Reset" : "Nulstil",
    "Cancel" : "Annuller",
    "Continue" : "Fortsæt",
    "Undo" : "Fortryd",
    "Redo" : "Annullér fortryd",
    "Original" : "Original",
    "Custom" : "Valgfrit",
    "Value" : "Værdi",
    "Image" : "Billede",
    "Line" : "Linje",
    "Text" : "Tekst",
    "Size" : "Størelse",
    "Position" : "Position",
    "Extension" : "Filtype",
    "Name is required." : "Navn er påkrævet."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-24.0.9.tgz: nextcloud/apps/viewer/l10n/da.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Fremviser",
    "Simple file viewer with slideshow for media" : "Simpel filfremviser med slideshow til medie-filer",
    "Your browser does not support audio." : "Din browser understøtter ikke lyd.",
    "Error loading {name}" : "Fejl ved indlæsning af {name}",
    "Image saved" : "Billede gemp",
    "Unsaved changes" : "Ikke gemte ændringer",
    "Your browser does not support videos." : "Din browser understøtter ikke videoer.",
    "Edit" : "Rediger",
    "Open sidebar" : "Åbn sidebar",
    "Download" : "Download",
    "Delete" : "Slet",
    "There is no plugin available to display this file type" : "Der er intet plugin tilgængeligt til at vise denne filtype",
    "View" : "Vis",
    "Name" : "Navn",
    "Save" : "Gem",
    "Back" : "Tilbage",
    "Loading …" : "Loading …",
    "Reset" : "Nulstil",
    "Cancel" : "Annuller",
    "Continue" : "Fortsæt",
    "Undo" : "Fortryd",
    "Redo" : "Annullér fortryd",
    "Zoom in" : "Zoom ind",
    "Original" : "Original",
    "Custom" : "Valgfrit",
    "Value" : "Værdi",
    "Image" : "Billede",
    "Line" : "Linje",
    "Text" : "Tekst",
    "Size" : "Størelse",
    "Position" : "Position",
    "Extension" : "Filtype",
    "Name is required." : "Navn er påkrævet.",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Vis dine seneste feriebilledes og videoer som i biografen, vis et glimt af din seneste roman direkte fra din Nextcloud, vis din bedste GIF i din samling gennem forhåndsvisning af dine favoritfiler og meget mere!"
},
"nplurals=2; plural=(n != 1);");
